@@ -15,16 +15,16 @@ def db():
 def cli():
 	'''Open an interactive MySQL shell on the production host'''
 	root = util.find_root()
-	sail_config = util.get_sail_config()
+	config = util.config()
 
-	click.echo('Spawning an interactive MySQL shell at %s' % sail_config['hostname'])
+	click.echo('Spawning an interactive MySQL shell at %s' % config['hostname'])
 
 	os.execlp('ssh', 'ssh', '-t',
 		'-i', '%s/.sail/ssh.key' % root,
 		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
 		'-o', 'IdentitiesOnly=yes',
 		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
-		'root@%s' % sail_config['hostname'],
+		'root@%s' % config['hostname'],
 		'docker exec -it sail sudo -u www-data wp --path=/var/www/public db cli'
 	)
 
@@ -33,7 +33,8 @@ def cli():
 def import_cmd(path):
 	'''Import a local .sql or .sql.gz file to the production MySQL database'''
 	root = util.find_root()
-	sail_config = util.get_sail_config()
+	config = util.config()
+	c = util.connection()
 
 	path = pathlib.Path(path).resolve()
 	if not path.exists():
@@ -50,7 +51,7 @@ def import_cmd(path):
 
 	args = ['-t']
 	source = path
-	destination = 'root@%s:/var/www/%s' % (sail_config['hostname'], temp_name)
+	destination = 'root@%s:/var/www/%s' % (config['hostname'], temp_name)
 	returncode, stdout, stderr = util.rsync(args, source, destination, default_filters=False)
 
 	if returncode != 0:
@@ -62,36 +63,16 @@ def import_cmd(path):
 	click.echo('- Importing database into MySQL')
 	cat_bin = 'zcat' if is_gz else 'cat'
 
-	p = subprocess.Popen(['ssh',
-		'-i', '%s/.sail/ssh.key' % root,
-		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
-		'-o', 'IdentitiesOnly=yes',
-		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
-		'root@%s' % sail_config['hostname'],
-		'docker exec sail bash -c "%s /var/www/%s | mysql -uroot wordpress"' % (cat_bin, temp_name)
-	])
-
-	while p.poll() is None:
-		util.loader()
-
-	if p.returncode != 0:
+	try:
+		c.run('docker exec sail bash -c "%s /var/www/%s | mysql -uroot wordpress"' % (cat_bin, temp_name))
+	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
 	click.echo('- Cleaning up production')
 
-	p = subprocess.Popen(['ssh',
-		'-i', '%s/.sail/ssh.key' % root,
-		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
-		'-o', 'IdentitiesOnly=yes',
-		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
-		'root@%s' % sail_config['hostname'],
-		'docker exec sail rm /var/www/%s' % temp_name
-	])
-
-	while p.poll() is None:
-		util.loader()
-
-	if p.returncode != 0:
+	try:
+		c.run('docker exec sail rm /var/www/%s' % temp_name)
+	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
 	click.echo('- Database imported')
@@ -100,7 +81,8 @@ def import_cmd(path):
 def export():
 	'''Export the production database to a local .sql.gz file'''
 	root = util.find_root()
-	sail_config = util.get_sail_config()
+	config = util.config()
+	c = util.connection()
 
 	backups_dir = pathlib.Path(root + '/.backups')
 	backups_dir.mkdir(parents=True, exist_ok=True)
@@ -108,25 +90,15 @@ def export():
 
 	click.echo('# Exporting WordPress database')
 
-	p = subprocess.Popen(['ssh',
-		'-i', '%s/.sail/ssh.key' % root,
-		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
-		'-o', 'IdentitiesOnly=yes',
-		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
-		'root@%s' % sail_config['hostname'],
-		'docker exec sail bash -c "mysqldump --quick --single-transaction --default-character-set=utf8mb4 -uroot wordpress | gzip -c9 > /var/www/%s"' % filename
-	])
-
-	while p.poll() is None:
-		util.loader()
-
-	if p.returncode != 0:
+	try:
+		c.run('docker exec sail bash -c "mysqldump --quick --single-transaction --default-character-set=utf8mb4 -uroot wordpress | gzip -c9 > /var/www/%s"' % filename)
+	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
 	click.echo('- Export completed, downloading')
 
 	args = ['-t']
-	source = 'root@%s:/var/www/%s' % (sail_config['hostname'], filename)
+	source = 'root@%s:/var/www/%s' % (config['hostname'], filename)
 	destination = '%s/%s' % (backups_dir, filename)
 	returncode, stdout, stderr = util.rsync(args, source, destination, default_filters=False)
 
@@ -135,19 +107,9 @@ def export():
 
 	click.echo('- Cleaning up production')
 
-	p = subprocess.Popen(['ssh',
-		'-i', '%s/.sail/ssh.key' % root,
-		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
-		'-o', 'IdentitiesOnly=yes',
-		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
-		'root@%s' % sail_config['hostname'],
-		'docker exec sail rm /var/www/%s' % filename
-	])
-
-	while p.poll() is None:
-		util.loader()
-
-	if p.returncode != 0:
+	try:
+		c.run('docker exec sail rm /var/www/%s' % filename)
+	except:
 		raise click.ClickException('An error occurred in SSH. Please try again.')
 
 	click.echo('- Database export saved to .backups/%s' % filename)
