@@ -2,6 +2,7 @@ from sail import cli, util
 
 import subprocess, time
 import click, pathlib
+import re, shlex
 
 def _get_extend_filters(paths, prefix=None):
 	root = util.find_root()
@@ -57,15 +58,15 @@ def _get_extend_filters(paths, prefix=None):
 def deploy(with_uploads, dry_run, path):
 	'''Deploy your working copy to production. If path is not specified then all application files are deployed.'''
 	root = util.find_root()
-	sail_config = util.get_sail_config()
+	config = util.config()
 
-	app_id = sail_config['app_id']
-	release_name = str(int(time.time()))
+	app_id = config['app_id']
+	release = str(int(time.time()))
 
 	if dry_run:
 		click.echo('# Comparing files')
 
-		destination = 'root@%s:/var/www/public/' % sail_config['hostname']
+		destination = 'root@%s:/var/www/public/' % config['hostname']
 		source = '%s/' % root
 		files = _diff(source, destination, _get_extend_filters(path))
 		empty = True
@@ -86,21 +87,10 @@ def deploy(with_uploads, dry_run, path):
 
 	click.echo('# Deploying to production')
 	click.echo('- Preparing release directory')
+	c = util.connection()
 
-	p = subprocess.Popen(['ssh',
-		'-i', '%s/.sail/ssh.key' % root,
-		'-o', 'UserKnownHostsFile="%s/.sail/known_hosts"' % root,
-		'-o', 'IdentitiesOnly=yes',
-		'-o', 'IdentityFile="%s/.sail/ssh.key"' % root,
-		'root@%s' % sail_config['hostname'],
-		'mkdir -p /var/www/releases/%s && rsync -rogtl /var/www/public/ /var/www/releases/%s' % (release_name, release_name)
-	])
-
-	while p.poll() is None:
-		util.loader()
-
-	if p.returncode != 0:
-		raise click.ClickException('An error occurred in SSH. Please try again.')
+	c.run('mkdir -p /var/www/releases/%s' % release)
+	c.run('rsync -rogtl /var/www/public/ /var/www/releases/%s' % release)
 
 	click.echo('- Uploading application files to production')
 
@@ -108,7 +98,7 @@ def deploy(with_uploads, dry_run, path):
 		args=['-rtl', '--rsync-path', 'sudo -u www-data rsync',
 			'--copy-dest', '/var/www/public/', '--delete'],
 		source='%s/' % root,
-		destination='root@%s:/var/www/releases/%s' % (sail_config['hostname'], release_name),
+		destination='root@%s:/var/www/releases/%s' % (config['hostname'], release),
 		extend_filters=_get_extend_filters(path)
 	)
 
@@ -122,7 +112,7 @@ def deploy(with_uploads, dry_run, path):
 		returncode, stdout, stderr = util.rsync(
 			args=['-rtl', '--rsync-path', 'sudo -u www-data rsync', '--delete'],
 			source='%s/wp-content/uploads/' % root,
-			destination='root@%s:/var/www/uploads/' % sail_config['hostname'],
+			destination='root@%s:/var/www/uploads/' % config['hostname'],
 			default_filters=False,
 			extend_filters=_get_extend_filters(path, 'wp-content/uploads')
 		)
@@ -130,72 +120,82 @@ def deploy(with_uploads, dry_run, path):
 		if returncode != 0:
 			raise click.ClickException('An error occurred during upload. Please try again.')
 
-	click.echo('- Requesting Sail API to deploy: %s' % release_name)
+	click.echo('- Deploying release: %s' % release)
 
-	data = util.request('/deploy/', json={'release': release_name})
-	task_id = data.get('task_id')
+	click.echo('- Updating symlinks')
+	c.run('sudo -u www-data ln -sfn /var/www/uploads /var/www/releases/%s/wp-content/uploads' % release)
+	c.run('sudo -u www-data ln -sfn /var/www/releases/%s /var/www/public' % release)
 
-	if not task_id:
-		raise click.ClickException('Could not obain a deploy task_id.')
+	click.echo('- Reloading services')
+	c.run('docker exec sail nginx -s reload')
+	c.run('docker exec sail kill -s USR2 $(docker exec sail cat /var/run/php/php7.4-fpm.pid)')
 
-	click.echo('- Scheduled successfully, waiting for deploy')
+	releases = c.run('ls /var/www/releases')
+	releases = re.findall('\d+', releases.stdout)
+	releases = [int(i) for i in releases]
 
-	try:
-		data = util.wait_for_task(task_id, timeout=300, interval=5)
-	except:
-		raise click.ClickException('Deploy failed')
+	keep = util.get_sail_default('keep')
+	if not keep:
+		keep = 5
 
-	click.echo('- Successfully deployed %s' % release_name)
+	keep = int(keep)
+	keep = max(keep, 2)
+	keep = min(keep, 30)
+
+	if len(releases) > keep:
+		click.echo('- Removing outdated releases')
+		remove = sorted(releases)[:len(releases)-keep]
+		for key in remove:
+			c.run(shlex.join(['rm', '-rf', '/var/www/releases/%s' % key]))
+
+	click.echo('- Successfully deployed %s' % release)
 
 @cli.command()
 @click.argument('release', required=False, type=int, nargs=1)
 @click.option('--releases', is_flag=True, help='Get a list of valid releases to rollback to')
 def rollback(release=None, releases=False):
 	'''Rollback production to a previous release'''
-	root = util.find_root()
-	sail_config = util.get_sail_config()
+	sail = util.config()
+	c = util.connection()
 
 	if releases or not release:
-		data = util.request('/rollback')
+		_releases = c.run('ls /var/www/releases')
+		_releases = re.findall('\d+', _releases.stdout)
+
+		if len(_releases) < 1:
+			raise click.ClickException('Could not find any releases')
+
+		try:
+			_current = c.run('readlink /var/www/public').stdout.strip().split('/')[-1]
+		except:
+			_current = '0'
+
 		click.echo('# Available releases:')
-		if data.get('releases', []):
-			for r in data.get('releases', []):
-				flags = '(current)' if r == data.get('current_release') else ''
-				click.echo('- %s %s' % (r, flags))
-
-			click.echo()
-			click.echo('Rollback with: sail rollback <release>')
-		else:
-			click.echo('- No releases found, perhaps you should deploy something')
+		for r in _releases:
+			flags = '(current)' if r == _current else ''
+			click.echo('- %s %s' % (r, flags))
 
+		click.echo()
+		click.echo('Rollback with: sail rollback <release>')
 		return
 
 	if release:
 		release = str(release)
 
-	click.echo()
-	click.echo('# Rolling back')
+	click.echo('# Rolling back to %s' % release)
 
-	if release:
-		click.echo('- Requesting Sail API to rollback: %s' % release)
-	else:
-		click.echo('- Requesting Sail API to rollback')
+	_releases = c.run('ls /var/www/releases').stdout.strip().split('\n')
+	if release not in _releases:
+		raise click.ClickException('Invalid release. To get a list run: sail rollback --releases')
 
-	data = util.request('/rollback/', json={'release': release})
-	task_id = data.get('task_id')
-	rollback_release = data.get('release')
+	click.echo('- Updating symlinks')
+	c.run('ln -sfn /var/www/releases/%s /var/www/public' % release)
 
-	if not task_id:
-		raise click.ClickException('Could not obain a rollback task_id.')
+	click.echo('- Reloading services')
+	c.run('docker exec sail nginx -s reload')
+	c.run('docker exec sail kill -s USR2 $(docker exec sail cat /var/run/php/php7.4-fpm.pid)')
 
-	click.echo('- Scheduled successfully, waiting for rollback')
-
-	try:
-		data = util.wait_for_task(task_id, timeout=300, interval=5)
-	except:
-		raise click.ClickException('Rollback failed')
-
-	click.echo('- Successfully rolled back to %s' % rollback_release)
+	click.echo('- Successfully rolled back to %s' % release)
 
 @cli.command()
 @click.argument('path', nargs=-1, required=False)
@@ -206,7 +206,7 @@ def rollback(release=None, releases=False):
 def download(path, yes, with_uploads, delete, dry_run):
 	'''Download files from production to your working copy'''
 	root = util.find_root()
-	sail_config = util.get_sail_config()
+	config = util.config()
 
 	if not yes and not dry_run:
 		click.confirm('Downloading files from production may overwrite '
@@ -214,13 +214,13 @@ def download(path, yes, with_uploads, delete, dry_run):
 			abort=True
 		)
 
-	app_id = sail_config['app_id']
+	app_id = config['app_id']
 	delete = ['--delete'] if delete else []
 
 	if dry_run:
 		click.echo('# Comparing files')
 
-		source = 'root@%s:/var/www/public/' % sail_config['hostname']
+		source = 'root@%s:/var/www/public/' % config['hostname']
 		destination = '%s/' % root
 		files = _diff(source, destination, _get_extend_filters(path))
 		empty = True
@@ -243,7 +243,7 @@ def download(path, yes, with_uploads, delete, dry_run):
 
 	returncode, stdout, stderr = util.rsync(
 		args=['-rtl'] + delete,
-		source='root@%s:/var/www/public/' % sail_config['hostname'],
+		source='root@%s:/var/www/public/' % config['hostname'],
 		destination='%s/' % root,
 		extend_filters=_get_extend_filters(path)
 	)
@@ -257,7 +257,7 @@ def download(path, yes, with_uploads, delete, dry_run):
 		# Download uploads from production
 		returncode, stdout, stderr = util.rsync(
 			args=['-rtl'] + delete,
-			source='root@%s:/var/www/uploads/' % sail_config['hostname'],
+			source='root@%s:/var/www/uploads/' % config['hostname'],
 			destination='%s/wp-content/uploads/' % root,
 			default_filters=False,
 			extend_filters=_get_extend_filters(path, 'wp-content/uploads')
